#!/bin/sh

#******************************************************************#
# Licensed Materials - Property of IBM                             #
# (C) Copyright IBM Corp. 2015  All Rights Reserved                #
# US Government Users Restricted Rights - Use, duplication or      #
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.#
#******************************************************************#
#                                                                  #
# Purpose of this script is to collect logs for CMwO, PowerVC,     #
# and PEDBG from the HMC, etc.                                     #
#                                                                  #
#                                                                  #
#******************************************************************#
# Collection summary :                                             #
#-----------                                                       #
# OpenStack|                                                       #
# ----------                                                       #
# collect logs in /var/log, collect /etc/ this directories         #
# ceilometer                                                       #
# chef-server                                                      #
# cinder                                                           #
# glance                                                           #
# heat                                                             #
# httpd                                                            #
# horizon                                                          #
# iaasgateway                                                      #
# keystone                                                         #
# neutron                                                          #
# nova                                                             #
# openvswitch                                                      #
# qpid                                                             #
# rabbit                                                           # 
# quantum                                                          #
#                                                                  #
# /var/log/messages                                                #
# /etc/cmwo-version* Version data 
# (To verify if fixpack was updated/applied to deployed topology) #
# /opt/ibm/cmwo/version/product.version (deployment server only)   #
# /var/chef/cache/chef-stacktrace.out                              #
# SCE logs in /var/opt/ibm/*                                       #
# /etc/vmware-discovery.conf                                       #
# rpm -qa                                                          #
# ifconfig -a                                                      #
# uname -a                                                         #
# service --status-all                                             #
# ovs-vsctl show                                                   #
# brctl show                                                       # 
# iptables -L                                                      #
# hostname                                                         #
# /var/chef/cache directory                                        #
# /etc/sysconfig/network-scripts/ifcfg*                            #
#                                                                  #
#----------                                                        #
# PowerVC |                                                        #
#----------                                                        #
# run /usr/bin/powervc-diag command                                #
#                                                                  #
#--------                                                          #
# PEDBG |                                                          #
#--------                                                          #
# run pedbg -c -q 3                                                #
#                                                                  #
#-----------------                                                 #
# SNAP from VIOS |                                                 #
#-----------------                                                 #
# run SNAP command                                                 #
#                                                                  #
#-----------                                                       #
# SCE logs |                                                       #
#-----------                                                       #
# run infocollect.sh script                                        #
#                                                                  #
#---------                                                         #
# PowerVP|                                                         #
#---------                                                         #
# /etc/opt/ibm/powervp/*                                           #
# /IBM/PowerVP                                                     #
# /var/log/power*                                                  #
#                                                                  #
#********************************************************************#
# @01 02/26/2015  NKN  Initial creation                              #
# @02 03/19/2015  NKN  Added SCE                                     #
# @03 04/16/2015  NKN  Added manual upload option                    #
# @04 04/30/2015  NKN  Adding option to restart CMwO services        #
# @05 10/09/2015  NKN  Adding config files                           #
#                      Fixed read section to handle backspace        #
#                      Removed infocollect.sh for CMwO collection    #
# @06 10/12/2015  NKN  Adding ovs-vsctl                              #
#                             service --status-all                   #
#                             iptables                               #
#                             brctl show                             #
# @07 10/24/2015  NKN  Removing the word controller node from CMwO   #
#                      collection                                    #
#                      Hardcode upload dir to /toibm/os400           #
# @08 11/09/2015  NKN  Added vmware-discovery.conf file for CMwO     #
# @09 02/12/2016  NKN  More data added to CMwO collection            #
# @10 04/12/2016  PSS  Collect cmo version from /etc ...             #
# @11 04/26/2016  NKN  Changed pedbg -c -q 3 to                      #
#                              pedbg -c -q 4                         #
# @12 05/12/2016  PSS  Added PowerVC ICM driver logs and configs     #
# @13 05/18/2016  PSS  Added "ps -aux" output for CMwO to Misc sec   #
# @14 09/30/2016  PSS  Added mgtool version, etc to log file         #
#                      Also will get k2 files that were missed by    #
#                      1.2.3 and 1.3.0 defect.                       #
# @15 12/06/2016  PSS  Added df output (filesystems.output.txt)      #
#                      Fixed so files preserve last modified date    #
# @16 01/17/2017  PSS  Added systemctl -a -r to CMWO and powervc     #
#                      Collect /usr/share/openstack-dashboard/       #
# @17 02/15/2017  PSS  Added sort to rpm -qa; "top" top-output.txt   #
# @18 06/16/2017  PSS  Added ICM-HA is now collected to ../HA_data   #
# @19 07/25/2017  PSS  Collect baremetal (ironic) logs and cfg       #
# @20 09/08/2017  PSS  Added netstat -s and fixed HA collect issue   #
# @21 10/25/2017  PSS  Moved dashboard logs to .gz to improve search #
# @22 03/14/2018  SLP  Collt /opt/ibm/powervc/logs/powervc-image.log #
#                            /var/opt/ibm/powervc/imgstaging/        #
#********************************************************************#
loop=1
dir="/tmp/"
# Current version of mgtool recorded in log: mgtoolver.log="03.14.2018" 

#--------------------#
# Upload function    #
#--------------------#
function upload()
{   
    echo " "
    echo "Do you want to upload to IBM via secure FTP?"
    echo "1) Yes"
    echo "2) No"
    read -e upload
    while [ $loop = 1 ]; do
       if [ "$upload" = "1" ]; then
          echo "Enter PMR# (xxxxx,yyy,ccc):"
          read -e pmr_
          pmr=${pmr_:0:5}
          branch=${pmr_:6:3}
          country=${pmr_:10:3}
          comma=${pmr_:5:1}
          comma=${pmr_:9:1}
          newfile=/tmp/$pmr.$branch.$country.$lclfile
          mv /tmp/$lclfile $newfile
          host="anonymous@sftp.ecurep.ibm.com"
          sftp $host <<EOF
          cd /toibm/os400
          put $newfile
          quit
EOF
          break
       fi
       if [ "$upload" = "2" ]; then
          break
       fi
       echo "Do you want to upload to IBM via secure FTP?"
       echo "1) Yes"
       echo "2) No"
       read -e upload
    done
} 

#---------------------------#
# Manual upload function    #
#---------------------------#
function upload2()
{   
   found=0
   echo " "
   echo "File to upload (for eg. /tmp/xxxxx.tar.gz):"
   read -e file_
   echo " "
   echo "Enter PMR# (xxxxx,yyy,ccc):"
   read pmr_
   loop=1
   while [ $loop = 1 ]; do
      pmr=${pmr_:0:5}
      branch=${pmr_:6:3}
      country=${pmr_:10:3}
      comma=${pmr_:5:1}
      if [ "$comma" = "," ]; then 
         found=$((found+1))
      fi
      comma=${pmr_:9:1} 
      if [ "$comma" = "," ]; then 
         found=$((found+1))
      fi
      if [ $found == 2 ]; then
         loop=0
      else
         echo " "
         echo "Enter a valid PMR# (xxxxx,yyy,ccc):"
         found=0
         read -e pmr_
      fi
   done

   #------------------------------------------------#
   # Extracting the '/' so we can get the file name #
   #------------------------------------------------#
   echo $file_ | grep -ob '/' > /tmp/daggity_value.txt                                      # Getting positions that match
   cat /tmp/daggity_value.txt| while read line;do echo $line > /tmp/daggity_pos.txt;done    # Grabbing last value
   pos=$(awk -F: '{ print $1 }' /tmp/daggity_pos.txt)                                       # Grabbing just the pos number 
   pos=$((pos + 1))                                                                         # Adding a 1 since position 1 is 0

   rm -rf /tmp/daggity_value.txt
   rm -rf /tmp/daggity_pos.txt

   file=$(echo ${file_:$pos})
   dir=$(echo ${file_:0:$pos})

   #---------------------#
   # Adding PMR# to file #
   #---------------------#
   file=$pmr.$branch.$country.$file
   newfile=$dir$file
   mv $file_ $newfile
   host="anonymous@sftp.ecurep.ibm.com"
    sftp $host <<EOF  
    cd /toibm/os400
    put $newfile
    quit
EOF

} 

#-------------------#
# Download function #
#-------------------#
function download()
{
    echo " "
    #echo -e "\033[1;37mCollection on remote done, hit enter to download data or q to exit\033[0m"  
    echo -e "Collection on remote done, hit enter to download data or q to exit"
    read enter 
    if [ "$enter" = "q" ] || [ "$enter" = "Q" ]; then
       downloaded=0
       return
    fi
    echo "Retrieving data via SCP using user "$user" at host "$host""
    if [ "$function" = "PEDBG" ]; then
       scp -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error $user@$host:/dump/HMClog*.zip /tmp/
       if [ "$?" = "1" ]; then
          echo "Data download failed"
          exit
       fi
    else     
       lclfile="$host"_"$rmtfile"
       echo $lclfile
       scp -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error $user@$host:/tmp/$rmtfile /tmp/$lclfile
       if [ "$?" = "1" ]; then
          echo "Data download failed"
          exit
       fi
       echo " "
      # echo -e "\033[1;37mData is in /tmp/"$lclfile"\033[0m"      
	  echo -e "Data is in /tmp/"$lclfile""
    fi
}
 
#---------------------#
# Rename HMClog file  #
#---------------------#
function renameHMCfile()
{
    rm -rf /tmp/pedbg.zip
    ls /tmp/ | grep "HMClog"|while read line;do echo $line > /tmp/lastfile.txt;done
    cat /tmp/lastfile.txt | while read line;do mv /tmp/$line /tmp/pedbg.zip;done
    rm -rf /tmp/lastfile.txt
}


#--------------#
# Main program #
#--------------#

clear
echo "**************************************************************"
echo "*                (C) COPYRIGHT IBM CORP. 2015                *" 
echo "*                                                            *"
echo "* Build date : 10/26/2015                                    *"
echo "* Note : Requires Python 2.6 or higher                       *"
echo "*                                                            *"
echo "* The purpose of this script is to assist in collecting data *"
echo "* on a remote system and to bring it back to the local       *"
echo "* system under /tmp.                                         *"
echo "*                                                            *" 
echo "* Select an option :                                         *"
echo "* ------------------                                         *"
echo "* 1) Collect OpenStack data on a node                        *"
echo "* 2) Collect PowerVC diag data on PowerVC node               *"
echo "* 3) Collect PEDBG data on HMC                               *"
echo "* 4) Collect SNAP data from VIOS host                        *"
echo "* 5) Collect SCE (Smart Cloud Entry logs)                    *"
echo "* 6) Restart CMwO services (Cloud Manager w/ OpenStack)      *"
echo "* 7) Collect PowerVP data on Linux/AIX host                  *"
echo "* 8) Upload a file to IBM                                    *" 
echo "* 9) quit                                                    *"
echo "**************************************************************"
echo "Select an option: "

while [ $loop = 1 ]; do
   read -e option
   if [ "$option" = "1" ]; then
      function="CMWO"
      clear
      echo "*-------------------------------------------------------*"
      echo "* This will collect logs for OpenStack by using these   *"
      echo "* steps:                                                *"
      echo "*                                                       *"
      echo "* - SSH into the remote host that is using OpenStack    *"
      echo "* - Collect logs for OpenStack                          *"
      echo "* - Using SCP to bring the data back to this host       *"
      echo "*-------------------------------------------------------*"
      echo " "
      echo "Remote host (quit to exit):"
      read -e host
      tmpvalue=$(echo "$host" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      echo "User ID (user root recommended, quit to exit):"
      read -e user
      tmpvalue=$(echo "$user" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      break
   fi
   if [ "$option" = "2" ]; then
      function="POWERVC"
      clear
      echo "*-------------------------------------------------------*"
      echo "* This will collect logs for PowerVC by these steps:    *"                                                                       
      echo "*                                                       *"
      echo "* - SSH into the remote host that is using PowerVC      *"
      echo "* - Collect logs for PowerVC                            *"
      echo "* - Using SCP to bring the data back to this host       *"
      echo "*-------------------------------------------------------*"
      echo " "
      echo "Remote host (quit to exit):"
      read -e host
      tmpvalue=$(echo "$host" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      echo "User ID (user root recommended, quit to exit):"
      read -e user
      tmpvalue=$(echo "$user" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      break
   fi

   if [ "$option" = "3" ]; then
      function="PEDBG"
      clear
      echo "*----------------------------------------------------------------------*"
      echo "* Note: HMC users hscroot and hscpe will be used for this.             *"
      echo "*       User hscpe must exist on the HMC.                              *"
      echo "*       Refer to section 1 of this URL for information on user hscpe : *"
      echo "*       http://www-01.ibm.com/support/docview.wss?uid=nas8N1018878     *"
      echo "*----------------------------------------------------------------------*"
      echo " "
      echo "Remote HMC (quit to exit):"
      read -e host
      tmpvalue=$(echo "$host" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      user="hscpe"
      break
   fi

   if [ "$option" = "4" ]; then
      function="SNAP"
      
      # Check to see if python is in the user's path
      python --version
      if [ "$?" != "0" ]; then
         exit
      fi
      echo "Python command not found..."
      break
   fi

   if [ "$option" = "5" ]; then
      function="SCE"
      clear
      echo "*-------------------------------------------------------*"
      echo "* This will collect logs for SCE by using these steps:  *"
      echo "*                                                       *"
      echo "* - SSH into the remote host with SCE                   *"
      echo "* - Run the command to grab the logs                    *"
      echo "* - Using SCP to bring the data back to this host       *"
      echo "--------------------------------------------------------*"
      echo " " 
      echo "Remote host (quit to exit):"
      read -e host
      tmpvalue=$(echo "$host" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      echo "User ID (user sysadmin or root recommended, quit to exit):"
      read -e user
      tmpvalue=$(echo "$user" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      break
   fi

   if [ "$option" = "6" ]; then
      function="restart"
      echo "User ID (user root recommended, quit to exit):"
      read -e user
      tmpvalue=$(echo "$user" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      echo "Remote host (quit to exit):"
      read -e host
      tmpvalue=$(echo "$host" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      break
   fi

   if [ "$option" = "7" ]; then
      function="PowerVP"
      clear
      echo "*-------------------------------------------------*"
      echo "* This will collect PowerVP logs from a remote    *"
      echo "* host using these steps:                         *"
      echo "*                                                 *"
      echo "* - SSH to the remote host                        *"
      echo "* - Collect the logs                              *"
      echo "* - Using SCP to bring back the data to this host *"
      echo "*-------------------------------------------------*"
      echo " "
      echo "Remote host (quit to exit):"
      read -e host
      tmpvalue=$(echo "$host" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      echo "User ID (user sysadmin or root recommended, quit to exit):"
      read -e user
      tmpvalue=$(echo "$user" | tr [a-z] [A-Z])  # Change to upper case
      if [ "$tmpvalue" = "QUIT" ]; then
         exit
      fi
      break
   fi

   if [ "$option" = "8" ]; then
      function="upload2"
      clear
      echo "*---------------------------------------------*"
      echo "* Upload a file to IBM to sftp.ecurep.ibm.com *"
      echo "* Use PMR in form of PPPPP,BBB,CCC            *"
      echo "*---------------------------------------------*"
      upload2
      exit
   fi

   if [ "$option" = "9" ]; then
      exit
   fi
   echo "Select an option: "
done


#--------------------------------------------------------------#
# CMwO data collection                                         #
#--------------------------------------------------------------#
if [ "$function" = "CMWO" ]; then
   echo " "
   echo "Starting SSH using user "$user" to "$host""
   ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error -t $user@$host ' 
   #!/bin/sh
   manual="1"
   rm -rf /tmp/qmgdata
   mkdir /tmp/qmgdata
   
   #-------------------#
   # Manual collection #
   #-------------------#
   if [ "$manual" = "1" ]; then
      cmo_lib_array=(ceilometer chef-server cinder glance heat httpd horizon iaasgateway keystone neutron nova openvswitch qpid quantum)
      num=0
      maxlib=15
      SCE_array=(SCE41 SCE42)
      SCEnum=0
      SCEmax=2
  
      #---------------------------#
      # Create the data directory #
      #---------------------------#                               
      mkdir /tmp/qmgdata/openstack
       
      #--------------#
      # Get version  #
      #--------------#
      if [ -d /opt/ibm/cmwo/version ]; then
         yes | cp -fp /opt/ibm/cmwo/version/product.version /tmp/qmgdata/openstack/
      fi
       

      #-------------------------------#
      # Copy over chef-stacktrace.out #
      #-------------------------------#
      if [ -d /var/chef/cache ]; then
         mkdir /tmp/qmgdata/openstack/chef_cache
         tar cvzf /tmp/qmgdata/openstack/chef_cache/cache_dir.tar.gz /var/chef/cache
         # yes | cp -fp /var/chef/cache/chef-stacktrace.out /tmp/qmgdata/openstack/
      fi

      #---------------------#
      # Copy the CMwO logs  #
      #---------------------#
      while [ $num -lt $maxlib ]; do    
         if [ -d /var/log/${cmo_lib_array[$num]} ]; then
            mkdir /tmp/qmgdata/openstack/${cmo_lib_array[$num]}
            yes | cp -fp /var/log/${cmo_lib_array[$num]}/*.log /tmp/qmgdata/openstack/${cmo_lib_array[$num]}
         fi
         let num=num+1
      done

      #------------------------#
      # Copy the CMwO configs  #
      #------------------------#
      num=0
      while [ $num -lt $maxlib ]; do    
         if [ -d /etc/${cmo_lib_array[$num]} ]; then
            mkdir /tmp/qmgdata/openstack/${cmo_lib_array[$num]}_configs
            yes | cp -rpf /etc/${cmo_lib_array[$num]}/ /tmp/qmgdata/openstack/${cmo_lib_array[$num]}_configs
         fi
         let num=num+1
      done
	  
      #---------------------#
      # Copy the PowerVC driver logs and configs (if exist)  #
      #---------------------# 
         if [ -d /var/log/powervc ]; then
            mkdir /tmp/qmgdata/openstack/powervc_logs/
            cp -fp /var/log/powervc/*.log /tmp/qmgdata/openstack/powervc_logs/
         fi
 
         if [ -d /etc/powervc ]; then
            mkdir /tmp/qmgdata/openstack/powervc_configs/
            cp -fp /etc/powervc/* /tmp/qmgdata/openstack/powervc_configs/
         fi

      #---------------------#
      # Copy the rabbitmq logs  #
      #---------------------#
         if [ -d /var/log/rabbitmq ]; then
            mkdir /tmp/qmgdata/openstack/rabbitmq
            cp -fp /var/log/rabbitmq/*.* /tmp/qmgdata/openstack/rabbitmq
         fi

      #---------------------#
      # Copy the baremetal (ironic) logs and configs (if exist)  #
      #---------------------#
	if [ -d /var/log/ironic ]; then
            mkdir /tmp/qmgdata/openstack/ironic_logs/
            cp -fp /var/log/ironic/*.log /tmp/qmgdata/openstack/ironic_logs/
         fi
 
         if [ -d /etc/ironic ]; then
            mkdir /tmp/qmgdata/openstack/ironic_cfgs/
            cp -fp /etc/powervc/* /tmp/qmgdata/openstack/ironic_cfgs/
         fi

      #------------#
      # SCExx logs #
      #------------#
      SCEnum=0
      while [ $SCEnum -lt $SCEmax ]; do
         if [ -d /var/opt/ibm/.${SCE_array[$SCEnum]} ]; then
            mkdir /tmp/qmgdata/${SCE_array[$SCEnum]}
            cp -fp /var/opt/ibm/.${SCE_array[$SCEnum]}/logs/*.log /tmp/qmgdata/${SCE_array[$SCEnum]}
         fi
         let SCEnum=SCEnum+1
      done

      #----------#
      # messages #
      #----------#
      cp -p /var/log/messages /tmp/qmgdata/openstack/

      #----------#
      # Version data (To verify if fixpack was updated/applied to deployed topology) #
      #----------#
      if [ -f /etc/cmwo-version ]; then
         mkdir /tmp/qmgdata/openstack/fixpack_update
         cp -p /etc/cmwo-version* /tmp/qmgdata/openstack/fixpack_update/
      fi
     
      #----------#
      # rpm -qa  #
      #----------#
      rpm -qa |sort > /tmp/qmgdata/openstack/rpm_qa.txt

      #----------#
      # HA data -- should only collect if cmwo_ha_status script exists #
      #----------#
      if [ -f /usr/sbin/cmwo_ha_status ]; then
        mkdir /tmp/qmgdata/openstack/HA_data
        if [ -f /var/log/pcsd/pcsd.log ]; then
            cp -p /var/log/pcsd/pcsd.log /tmp/qmgdata/openstack/HA_data/
         fi
        if [ -f /var/log/pacemaker.log ]; then
            cp -p /var/log/pacemaker.log /tmp/qmgdata/openstack/HA_data/pacemaker.log
         fi
        if [ -f /var/log/cluster/corosync.log ]; then
            cp -p /var/log/cluster/corosync.log /tmp/qmgdata/openstack/HA_data/corosync.log
         fi
        if [ -f /etc/corosync/corosync.conf ]; then
            cp -p /etc/corosync/corosync.conf /tmp/qmgdata/openstack/HA_data/corosync.conf
         fi
      
      ### get status of various components ###
      cmwo_db2hadr_status &>/tmp/qmgdata/openstack/HA_data/cmwo_db2hadr_status.txt
      cmwo_ha_status &>/tmp/qmgdata/openstack/HA_data/cmwo_ha_status.txt
      cmwo_rabbitmq_status &>/tmp/qmgdata/openstack/HA_data/cmwo_rabbitmq_status.txt
      pcs status &>/tmp/qmgdata/openstack/HA_data/pcs_status.txt

      fi

      #-----------#
      # Misc data #
      #-----------#         
      echo "Printing interfaces..." > /tmp/qmgdata/openstack/ifconfig.txt
      echo "----------------------" >> /tmp/qmgdata/openstack/ifconfig.txt
      ip a >> /tmp/qmgdata/openstack/ifconfig.txt
      echo "." >> /tmp/qmgdata/openstack/ifconfig.txt
      echo "." >> /tmp/qmgdata/openstack/ifconfig.txt
      echo "Printing routing table" >> /tmp/qmgdata/openstack/ifconfig.txt
      echo "----------------------" >> /tmp/qmgdata/openstack/ifconfig.txt
      ip r >> /tmp/qmgdata/openstack/ifconfig.txt
      cat /etc/*release > /tmp/qmgdata/openstack/os_release.txt
      uname -a > /tmp/qmgdata/openstack/uname.txt
      netstat -s > /tmp/qmgdata/openstack/netstat_stats.txt
      hostname > /tmp/qmgdata/openstack/hostname.txt
      service --status-all > /tmp/qmgdata/openstack/service_status_all.txt
      ovs-vsctl show > /tmp/qmgdata/openstack/ovs-vsctl_show.txt
      brctl show > /tmp/qmgdata/openstack/brctl_show.txt
      iptables -L > /tmp/qmgdata/openstack/iptables.txt
      df -ha > /tmp/qmgdata/openstack/df-output.txt
      ps -aux > /tmp/qmgdata/openstack/ps_aux.txt
      top -n 1 -b > /tmp/qmgdata/openstack/top-output.txt
      date > /tmp/qmgdata/openstack/date.txt
      echo "ls -la /var/log/ ..."
      ls -la /var/log >> /tmp/qmgdata/openstack/var-log-dirlist.txt
      echo "ls -la /opt/ibm/ ..."
      ls -la /opt/ibm >> /tmp/qmgdata/openstack/opt-ibm-dirlist.txt

      if [ -f /usr/bin/systemctl ]; then
         systemctl -a -r >/tmp/qmgdata/openstack/systemctl_out.txt 
      fi
      
      if [ -f /etc/vmware-discovery.conf ]; then
         cp -p /etc/vmware-discovery.conf /tmp/qmgdata/openstack/vmware-discovery.conf
      fi
   
      if [ -d /etc/sysconfig/network-scripts ]; then
         mkdir /tmp/qmgdata/openstack/network-scripts/
         cp -fp /etc/sysconfig/network-scripts/ifcfg* /tmp/qmgdata/openstack/network-scripts/
      fi

      if [ -d /usr/share/openstack-dashboard ]; then
         mkdir /tmp/qmgdata/openstack/openstack-dashboard/
         tar cvzf /tmp/qmgdata/openstack/openstack-dashboard/openstack-dashboard_dir.tar.gz /usr/share/openstack-dashboard
      fi

      #-----------------#
      # zip up the data #
      #-----------------#
      # add the mgtool version file first
      echo "mgtool version is: 10.25.2017" > /tmp/qmgdata/mgtoolver.log 
      tar cvzf /tmp/cmwo_data.tar.gz /tmp/qmgdata/ 

      echo "CMwO data save in /tmp/cmwo_data.tar.gz"
      good=1
      exit $good
   fi
' 
   if [ "$?" = "1" ]; then
      rmtfile="cmwo_data.tar.gz"
      download
      if [ "$downloaded" = "0" ]; then
         echo -e "\033[1;37mData is in /tmp/"$rmtfile" on "$host"\033[0m"  
         exit
      fi
      upload
      exit
   fi
   echo " "
   echo "Data collection failed"   
fi

#--------------------------------------------------------------#
# PowerVC data collection                                      #
#--------------------------------------------------------------#
if [ "$function" = "POWERVC" ]; then
   echo " "
   echo "Starting SSH using user "$user" to "$host""
   ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error -t $user@$host '
   #!/bin/sh
   if [ -f /usr/bin/powervc-diag ]; then
      rm -rf /tmp/qmgdata_powervc
      mkdir /tmp/qmgdata_powervc
#--- Get directories missed by powervc-diag ---#
      ver=$(tail -6 /opt/ibm/powervc/version.properties | grep version)
      vertrim=${ver:10:5}	
      if [ "$vertrim" = "1.3.0" ] || [ "$vertrim" = "1.2.3" ] ; then
        if [ -d /var/log/cinder/k2a-ffdc ]; then
           tar cvzf /tmp/qmgdata_powervc/k2-cinderlogs.tar.gz /var/log/cinder/k2a-ffdc
        fi
        if [ -d /var/log/nova/k2a-ffdc ]; then
           tar cvzf /tmp/qmgdata_powervc/k2-novalogs.tar.gz /var/log/nova/k2a-ffdc
        fi
        if [ -d /opt/ibm/powervc/logs/powervc-image.log ]; then
           tar cvzf /tmp/qmgdata_powervc/powervc-image.log.tar.gz /opt/ibm/powervc/logs/powervc-image.log
        fi
        if [ -d /var/opt/ibm/powervc/imgstaging/ ]; then
           tar cvzf /tmp/qmgdata_powervc/imgstaging.tar.gz /var/opt/ibm/powervc/imgstaging
        fi
      fi
#--- end of Get directories missed ---#
      echo " "
      echo "You might be prompted for root password..."
      yes | /usr/bin/powervc-diag  -o /tmp/qmgdata_powervc -f powervc-diag
      echo "Collecting addtional data..."
      cp /opt/ibm/powervc/version.properties /tmp/qmgdata_powervc/version.properties
      ifconfig -a > /tmp/qmgdata_powervc/ifconfig.txt
      cat /etc/*release > /tmp/qmgdata_powervc/os_level.txt
      uname -a > /tmp/qmgdata_powervc/uname.txt
      rpm -qa |sort > /tmp/qmgdata_powervc/rpm_qa.txt
      top -n 1 -b > /tmp/qmgdata_powervc/top-output.txt

      if [ -f /usr/bin/systemctl ]; then
         systemctl -a -r >/tmp/qmgdata_powervc/systemctl_out.txt 
      fi

      # add the mgtool version file
      echo "mgtool version is: 10.25.2017" > /tmp/qmgdata_powervc/mgtoolver.log
      echo "Creating tar file..."
      tar cvzf /tmp/powervc_data.tar.gz /tmp/qmgdata_powervc/
      data=1
      exit $data
   fi    
   data=0
   exit $data'

   if [ "$?" = "1" ]; then
      rmtfile="powervc_data.tar.gz"
      download
      if [ "$downloaded" = "0" ]; then
         echo -e "\033[1;37mData is in /tmp/"$rmtfile" on remote system\033[0m"  
         exit
      fi
      upload
      exit
   fi
   echo "Missing /usr/bin/powervc-diag...make sure you are on the right node"
   echo "Data collection failed"
   exit
fi

#--------------------------------------------------------------#
# PEDBG data collection                                        #
#--------------------------------------------------------------#
if [ "$function" = "PEDBG" ]; then 
   echo "  "
   echo "Starting SSH using user hscpe to "$host""
   ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -t -o LogLevel=error $user@$host '
   #!/bin/sh
   pedbg -c -q 4
   if [ "$?" = "0" ]; then
      good=1
      exit $good
   fi'
   
   if [ "$?" = "1" ]; then
      user="hscroot"
      download
      if [ "$downloaded" = "0" ]; then
         echo -e "\033[1;37mData is in /dump/HMClog*.zip on remote system\033[0m"  
         exit
      fi
      renameHMCfile
      lclfile="pedbg.zip"
      echo " "
      echo -e "\033[1;37mData is in /tmp/"$lclfile"\033[0m" 
      upload
      exit
   fi    
   echo "Data collection failed"
   exit 
fi        

#--------------------------------------------------------------#
# VIOS data collection                                         #
#--------------------------------------------------------------#
if [ "$function" = "SNAP" ]; then
   rm -rf ./data_area
   python ./vios_snap.pyc
   ls -l ./data_area
   if [ "$?" != "0" ];then
      exit
   fi
   lclfile=$(cat ./data_area)
   upload
   exit
fi

#--------------------------------------------------------------#
# SCE data collection                                          #
#--------------------------------------------------------------#
if [ "$function" = "SCE" ]; then
   echo " "
   echo "Starting SSH using user "$user" to "$host""
   ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error -t $user@$host ' 
   #!/bin/sh
   manual="1"
   rm -rf /tmp/qmgdata
   mkdir /tmp/qmgdata
 
   #--------------------------------------------------------------#
   # Find the infocollect.sh and then find the location of .SCExx #
   #--------------------------------------------------------------#
   sce_dir=$(ls /opt/ibm/ | grep "SCE")
   if [ -f /opt/ibm/$sce_dir/program/bin/infocollect.sh ]; then
      if [ -d /var/opt/ibm/.$sce_dir ]; then
         /opt/ibm/$sce_dir/program/bin/infocollect.sh -c /var/opt/ibm/.$sce_dir -d /tmp/qmgdata
         rpm -qa > /tmp/qmgdata/rpm_qa.txt
         date > /tmp/qmgdata/date.txt
         tar cvzf /tmp/sce_data.tar.gz /tmp/qmgdata/
         good=1
         exit $good
      else
         if  [ -d /home/sysadmin/.$sce_dir ]; then
            /opt/ibm/$sce_dir/program/bin/infocollect.sh -c /home/sysadmin/.$sce_dir -d /tmp/qmgdata
            rpm -qa > /tmp/qmgdata/rpm_qa.txt
            date > /tmp/qmgdata/date.txt
            tar cvzf /tmp/sce_data.tar.gz /tmp/qmgdata/
            good=1
            exit $good
         fi
      fi
   fi
  
' 
   if [ "$?" = "1" ]; then
      rmtfile="sce_data.tar.gz"
      download
      if [ "$downloaded" = "0" ]; then
         echo -e "\033[1;37mData is in /tmp/"$rmtfile" on remote system\033[0m"  
         exit
      fi
      upload
      exit
   fi
   echo " "
   echo "Data collection failed"   
fi



if [ "$function" = "restart" ]; then
   echo " "
   echo "Starting SSH using user "$user" to "$host""
   ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error -t $user@$host "
   #!/bin/sh
   #--------------------------#
   # Get openstack services   #
   #--------------------------#
   service --status-all | grep "openstack-" | grep "running" > /tmp/openstack_services.txt
   service --status-all | grep "neutron" | grep "running" > /tmp/neutron_services.txt
   awk '{ print \$1 }' /tmp/openstack_services.txt > /tmp/openstack_services_1.txt 
   awk '{ print \$1 }' /tmp/neutron_services.txt > /tmp/neutron_services_1.txt
   cat /tmp/openstack_services_1.txt > /tmp/qmgtools_cmwo_services.txt
   cat /tmp/neutron_services_1.txt >> /tmp/qmgtools_cmwo_services.txt
   service db2.service status | grep -i "running"
   if [ "\$?" == "0" ]; then
      echo "db2.service" >> /tmp/qmgtools_cmwo_services.txt
   fi
   service db2.nosql.service status | grep -i "running"
   if [ "\$?" == "0" ]; then
      echo "db2.nosql.service" >> /tmp/qmgtools_cmwo_services.txt
   fi
   service mysqld status | grep -i "running"
   if [ "\$?" == "0" ]; then
      echo "mysqld" >> /tmp/qmgtools_cmwo_services.txt
   fi
   service rabbitmq-server status | grep -i "pid"
   if [ "\$?" == "0" ]; then
     #echo "rabbitmq-server" >> /tmp/qmgtools_cmwo_services.txt
      echo "rabbitmq-server" > /tmp/qmgtools_cmwo_manual_start.txt
   fi
   service qpidd status | grep -i "running" 
   if [ "\$?" == "0" ]; then
      echo "qpidd" >> /tmp/qmgtools_cmwo_services.txt
   fi
   service sce status | grep -i "running"
   if [ "\$?" == "0" ]; then
      echo "sce" >> /tmp/qmgtools_cmwo_services.txt
   fi
   service tgtd status | grep -i "running"
   if [ "\$?" == "0" ]; then
      echo "tgtd" >> /tmp/qmgtools_cmwo_services.txt
   fi
   cat /tmp/qmgtools_cmwo_services.txt | grep -Fx  neutron
   if [ "\$?" == "0" ]; then
      cat  /tmp/qmgtools_cmwo_services.txt | grep -vFx  neutron > /tmp/qmgtools_cmwo_services_1.txt
      echo "neutron-server" >> /tmp/qmgtools_cmwo_services_1.txt
      cat /tmp/qmgtools_cmwo_services_1.txt > /tmp/qmgtools_cmwo_services.txt
      rm -rf /tmp/qmgtools_cmwo_services_1.txt
   fi
   cat /tmp/qmgtools_cmwo_services.txt | grep -i "openstack-ceilometer-agent-notification"
   if [ "\$?" == "0" ]; then
      service openstack-ceilometer-agent-notification status
      if [ "\$?" != "0" ]; then
         cat /tmp/qmgtools_cmwo_services.txt | grep -v "openstack-ceilometer-agent-notification" > /tmp/qmgtools_cmwo_services_1.txt 
         echo "openstack-ceilometer-notification" >> /tmp/qmgtools_cmwo_services_1.txt
         cat /tmp/qmgtools_cmwo_services_1.txt > /tmp/qmgtools_cmwo_services.txt
         rm -rf /tmp/qmgtools_cmwo_services_1.txt
      fi
   fi   
   service openstack-nova-scheduler status | grep -i "running"
   if [ "\$?" == "0" ]; then
      echo "memcached" >> /tmp/qmgtools_cmwo_services.txt 
      #echo "httpd" >> /tmp/qmgtools_cmwo_services.txt 
      echo "httpd" >> /tmp/qmgtools_cmwo_manual_start.txt
   fi

   #----------------------#
   # Restart the services #
   #----------------------#
   cat /tmp/qmgtools_cmwo_services.txt | while read line; do
   echo "Restarting service: \$line";
   service \$line restart;
   done     

   cat /tmp/qmgtools_cmwo_manual_start.txt | while read line; do
   echo "Restarting service: \$line";
   service \$line stop;
   sleep 5
   service \$line start;
   done   

"
fi    

#--------------------------------------------------------------#
# PowerVP data collection                                      #
#--------------------------------------------------------------#
if [ "$function" = "PowerVP" ]; then
   echo " "
   echo "Starting SSH using user "$user" to "$host""
   ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o LogLevel=error -t $user@$host ' 
   #!/bin/sh
   rm -rf /tmp/qmgdata_powervp
   rm -rf /tmp/qmgdata  
   mkdir /tmp/qmgdata

   #-----------------------#
   # Get some config files #
   #-----------------------#
   cp -fpr /etc/opt/ibm/powervp/* /tmp/qmgdata/

   #-----------------------------#
   # Installation files if exist #
   #-----------------------------#
   if [ -d /IBM/PowerVP ]; then
      rm -rf /tmp/qmgdata/IBM_PowerVP_Install_dir.tar
      tar cvf /tmp/qmgdata/IBM_PowerVP_Install_dir.tar /IBM/PowerVP   
   fi
   
   #--------------#
   # PowerVP log  #
   #--------------#
   cp -fp /var/log/power* /tmp/qmgdata/

   #--------------#
   # Misc data    #
   #--------------#
   ifconfig -a > /tmp/qmgdata/ifconfig.txt
   uname -a > /tmp/qmgdata/uname.txt
   
   #-----------#
   # Save data #
   #-----------#
   rm -rf /tmp/powervp_data.tar
   tar cvf /tmp/powervp_data.tar /tmp/qmgdata
   if [ "?" == "1" ]; then
      echo "PowerVP collection failed"
      good=0 
      exit $good
   else    
      echo "PowerVP data saved in /tmp/powervp_data.tar"
      good=1 
      exit $good
   fi
  

' 
   if [ "$?" = "1" ]; then
      rmtfile="powervp_data.tar"
      download
      if [ "$downloaded" = "0" ]; then
         echo -e "\033[1;37mData is in /tmp/"$rmtfile" on remote system\033[0m"  
         exit
      fi
      upload
      exit
   fi
   echo " "
   echo "Data collection failed" 

fi

#--------------------------------------------------------------#
# Help text                                                    #
#--------------------------------------------------------------#

   netstat
